@@ -1,6 +1,7 @@
 import logging
 import time
 import sys
+import json
 
 import asyncio
 import tarfile
@@ -10,11 +11,15 @@ import shutil
 from pathlib import Path
 from aiofile import async_open
 from azure.storage.blob.aio import BlobServiceClient
+from azure.eventhub.aio import EventHubProducerClient
+from azure.eventhub import EventData
 
 class Decompressor():
 
-    def __init__(self, conn_str):
+    def __init__(self, conn_str, eventhub_conn_str, eventhub_name):
         self.conn_str = conn_str
+        self.eventhub_conn_str = eventhub_conn_str
+        self.eventhub_name = eventhub_name
 
     async def process_blob_files(self, container_name, source_dir, dest_dir, local_temp_dir):
         try:
@@ -88,7 +93,26 @@ class Decompressor():
         blob_client = blob_service_client.get_blob_client(container=container_name, blob="{}/{}".format(dest_dir, blob_name))
 
         async with async_open(file, "rb") as afp:
-            await blob_client.upload_blob(await afp.read(), overwrite=True)      
+            await blob_client.upload_blob(await afp.read(), overwrite=True)     
+
+        properties = await blob_client.get_blob_properties()
+        metadata = properties.metadata
+        metadata_json = json.dumps(metadata)
+
+        producer = EventHubProducerClient.from_connection_string(
+            conn_str=self.eventhub_conn_str,
+            eventhub_name=self.eventhub_name,
+        )
+
+        async with producer:
+            # Create a batch.
+            event_data_batch = await producer.create_batch()
+
+            # Add events to the batch.
+            event_data_batch.add(EventData(metadata_json))
+
+            # Send the batch of events to the event hub.
+            await producer.send_batch(event_data_batch)
 
     def decompress(self, downloaded_file):   
         decompression_dir = os.path.splitext(downloaded_file)[0]
