@@ -1,8 +1,6 @@
 import asyncio
 from pathlib import Path
 from aiofile import async_open
-from azure.storage.blob.aio import BlobServiceClient
-from azure.core.exceptions import ResourceNotFoundError, ResourceExistsError
 from azure_blob_processor import Decompressor
 
 # constants
